package
module
Version:
v0.0.0-...-a13d8ea
Opens a new window with list of versions in this module.
Published: Dec 27, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Documentation
¶
func New2Src(src map[string]interface{}, new map[string]interface{})
func Src2New(src, new map[string]interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.